@@ -463,6 +463,11 @@ class CycleAndChainModel(Model):
                 obj.value(self._graph, exchange) * self._var_from_exchange(exchange)
                 for exchange in exchanges
             )
+            # If there is nothing in the objective function, we skip it.
+            # Otherwise, PuLP sometimes has issues.
+            if not obj_equation:
+                self._objective_values.append(0)
+                continue
             self += obj_equation
             self.sense = obj.sense.toObjective()
             solver = pulp.getSolver("PULP_CBC_CMD", msg=False)
