@@ -129,14 +129,27 @@ def test_instance_threeb_cycles(test_threeb):
     cycles = graph.findCycles(3)
     build_alternates_and_embeds(cycles)
     assert len(cycles) == 7
-    cycle_indices = [[int(v.donor.id) for v in cycle] for cycle in cycles]
-    assert [1, 2] in cycle_indices
-    assert [1, 2, 3] in cycle_indices
-    assert [1, 3] in cycle_indices
-    assert [1, 3, 4] in cycle_indices
-    assert [1, 4] in cycle_indices
-    assert [1, 4, 3] in cycle_indices
-    assert [3, 4] in cycle_indices
+    checked = 0
+    for cycle in cycles:
+        indices = [int(v.donor.id) for v in cycle]
+        if [1, 2] == indices:
+            checked += 1
+        if [1, 2, 3] == indices:
+            checked += 1
+            assert cycle.num_backarcs_uk() == 2
+        if [1, 3] == indices:
+            checked += 1
+        if [1, 3, 4] == indices:
+            assert cycle.num_backarcs_uk() == 3
+            checked += 1
+        if [1, 4] == indices:
+            checked += 1
+        if [1, 4, 3] == indices:
+            assert cycle.num_backarcs_uk() == 3
+            checked += 1
+        if [3, 4] == indices:
+            checked += 1
+    assert checked == 7
 
     cycles = graph.findCycles(2)
     assert len(cycles) == 4
@@ -268,6 +281,33 @@ def test_eight_backarcs():
     assert checked == 1
 
 
+def test_instance_eightb_backarcs():
+    instance = fileio.read_json("tests/test_instances/test8b.json")
+    graph = CompatibilityGraph(instance)
+    cycles = graph.findCycles(3)
+    build_alternates_and_embeds(cycles)
+    assert len(cycles) == 9
+    checked = 0
+    for cycle in cycles:
+        indices = [int(v.donor.id) for v in cycle]
+        print(indices)
+        if [1, 2] == indices:
+            checked += 1
+        if [1, 3] == indices:
+            checked += 1
+        if [1, 3, 4] == indices:
+            assert cycle.num_backarcs_uk() == 3
+            checked += 1
+        if [1, 4] == indices:
+            checked += 1
+        if [1, 4, 3] == indices:
+            assert cycle.num_backarcs_uk() == 3
+            checked += 1
+        if [3, 4] == indices:
+            checked += 1
+    assert checked == 6
+
+
 def test_cycle_finding_medium1():
     instance = fileio.read_json("tests/test_instances/medium-1.json")
     graph = CompatibilityGraph(instance)
